@@ -1,6 +1,6 @@
 /* Functions to handle callbacks for Aris.
 
-   Copyright (C) 2012 Ian Dunn.
+   Copyright (C) 2012, 2013 Ian Dunn.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@
 #include <string.h>
 #include <stdlib.h>
 #include <time.h>
+#include <math.h>
 
 #include "callbacks.h"
 #include "app.h"
@@ -39,18 +40,7 @@
 #include "var.h"
 #include "interop-isar.h"
 #include "proof.h"
-
-// Menu order from aris proof.
-
-enum MENU_ORDER {
-  FILE_MENU = 0,
-  EDIT_MENU,
-  PROOF_MENU,
-  RULES_MENU,
-  FONT_MENU,
-  HELP_MENU,
-  NUM_MENUS
-};
+#include "conf-file.h"
 
 /* Check gtk+ documentation for more information about signals. */
 
@@ -344,9 +334,15 @@ rule_menu_activated (GtkMenuItem * menuitem, gpointer data)
     case MENU_NEW:
       gui_new ();
       break;
+
     case MENU_OPEN:
       gui_open (the_app->rt->window);
       break;
+
+    case MENU_SUBMIT:
+      gui_submit_show (the_app->rt->window);
+      break;
+
     case MENU_QUIT:
       app_quit ();
       break;
@@ -396,6 +392,11 @@ rule_menu_activated (GtkMenuItem * menuitem, gpointer data)
     case MENU_CONTENTS:
       gui_help ();
       break;
+
+    case MENU_CUSTOMIZE:
+      gui_customize_show (rt->window);
+      break;
+
     case MENU_ABOUT:
       gui_about (the_app->rt->window);
       break;
@@ -415,6 +416,31 @@ rules_table_deleted (GtkWidget * widget, GdkEvent * event, gpointer data)
   return TRUE;
 }
 
+/* Minimizes the open proofs when the rules table is minimized.
+ *  output:
+ *    FALSE to continue propogation.
+ */
+G_MODULE_EXPORT gboolean
+rules_table_state (GtkWidget * widget, GdkEvent * event, gpointer data)
+{
+  GdkEventWindowState * ev = (GdkEventWindowState *) event;
+
+  if (ev->changed_mask == GDK_WINDOW_STATE_ICONIFIED)
+    {
+      item_t * app_itr;
+
+      for (app_itr = the_app->guis->head; app_itr; app_itr = app_itr->next)
+	{
+	  aris_proof * ap;
+	  ap = app_itr->value;
+
+	  gtk_window_iconify (GTK_WINDOW (ap->window));
+	}
+    }
+
+  return FALSE;
+}
+
 /* Destroys an aris proof, checking if it has unsaved changes.
  *  input:
  *    ap - the aris proof to destroy.
@@ -453,68 +479,6 @@ gui_destroy (aris_proof * ap)
   return 0;
 }
 
-/* Copies a sentence in an aris proof.
- *  input:
- *    ap - the aris proof containing the sentence being copied.
- *    sen - the sentence being copied.
- *  output:
- *    0 on success, -1 on error.
- */
-item_t *
-gui_copy (aris_proof * ap, sentence * sen)
-{
-  item_t * yanked;
-
-  yanked = (item_t *) calloc (1, sizeof (item_t));
-  CHECK_ALLOC (yanked, NULL);
-
-  yanked->value = (void *) sentence_copy_to_data (sen);
-  if (!yanked->value)
-    return NULL;
-
-  return yanked;
-}
-
-/* Kills a sentence in an aris proof.
- *  input:
- *    ap - the aris proof containing the sentence being killed.
- *    sen - the sentence being killed.
- *  output:
- *    0 on success, -1 on error.
- */
-item_t *
-gui_kill (aris_proof * ap, sentence * sen)
-{
-  item_t * yanked;
-  yanked = gui_copy (ap, sen);
-  if (!yanked)
-    return NULL;
-
-  int ret = aris_proof_remove_sentence (ap, sen);
-  if (ret < 0)
-    return NULL;
-
-  return yanked;
-}
-
-/* Yanks a sentence in an aris proof.
- *  input:
- *    ap - the aris proof to which the sentence is being yanked.
- *  output:
- *    0 on success, -1 on error.
- */
-int
-gui_yank (aris_proof * ap)
-{
-  sentence * sen;
-  /*
-  sen = aris_proof_create_sentence (ap, (sen_data *) ap->yanked->value);
-  if (!sen)
-    return -1;
-  */
-  return 0;
-}
-
 /* Creates a new aris proof gui.
  *  input:
  *    none.
@@ -563,6 +527,11 @@ gui_open (GtkWidget * window)
   gtk_file_chooser_set_select_multiple (GTK_FILE_CHOOSER (file_chooser), FALSE);
   gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (file_chooser), file_filter);
 
+  // First time, it happened in here.
+  // It tried loading the dialog, but didn't get far enough.
+  // free(): invalid pointer 874f10
+  // gtk_dialog_run
+
   if (gtk_dialog_run (GTK_DIALOG (file_chooser)) == GTK_RESPONSE_ACCEPT)
     {
       char * filename;
@@ -762,14 +731,21 @@ evaluate_line (aris_proof * ap, sentence * sen)
   sentence_set_value (sen, ret);
   aris_proof_set_sb (ap, ret_str);
 
-  for (ev_itr = lines->head; ev_itr; ev_itr = ev_itr->next)
+  for (ev_itr = lines->head; ev_itr;)
     {
       sen_data * sd;
+      item_t * n_itr;
+
       sd = ev_itr->value;
       sen_data_destroy (sd);
+
+      n_itr = ev_itr->next;
+      ev_itr->next = ev_itr->prev = NULL;
+      free (ev_itr);
+      ev_itr = n_itr;
     }
 
-  destroy_list (lines);
+  free (lines);
 
   return ret;
 }
@@ -933,17 +909,17 @@ int
 gui_about (GtkWidget * window)
 {
   const char * authors[] = {
-    _("Ian Dunn <scholar42@gmail.com>"),
+    _("Ian Dunn <dunni@gnu.org>"),
     NULL
   };
 
   const char * artists[] = {
-    _("Ian Dunn <scholar42@gmail.com>"),
+    _("Ian Dunn <dunni@gnu.org>"),
     NULL
   };
 
   const char * documenters[] = {
-    _("Ian Dunn <scholar42@gmail.com>"),
+    _("Ian Dunn <dunni@gnu.org>"),
     NULL
   };
 
@@ -967,7 +943,7 @@ Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.");
 			 "comments", _("  GNU Aris is a logical proof program, which supports both propositional and predicate logic, as well as Boolean algebra and arithmetical logic in the form of abstract sequences."),
 			 "logo", the_app->icon,
 			 "wrap-license", TRUE,
-			 "website", _("<http://www.gnu.org/software/aris/>"),
+			 "website", _("http://www.gnu.org/software/aris/"),
 			 NULL);
 
   return 0;
@@ -982,19 +958,397 @@ Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.");
 int
 gui_help ()
 {
-  //printf ("help file: %s\n", the_app->help_file);
   gboolean ret = gtk_show_uri (NULL, the_app->help_file, GDK_CURRENT_TIME, NULL);
-  if (!ret && 1)
+
+  if (!ret)
     {
-      fprintf (stderr,
-	       "Warning - Unable to open help file %s\n", the_app->help_file);
-      fprintf (stderr, "Try checking http://www.gnu.org/software/aris/manual/ for the online manual.\n");
-      return -1;
+      gtk_show_uri (NULL, "http://www.gnu.org/software/aris/manual/",
+		    GDK_CURRENT_TIME, NULL);
     }
 
   return 0;
 }
 
+/* Runs the customization dialog.
+ *  input:
+ *   window - The parent window of the dialog.
+ *  output:
+ *   0 on success, -1 on memory error, -2 on file error.
+ */
+int
+gui_customize_show (GtkWidget * window)
+{
+
+  GtkWidget * content, * dialog, * main_kc_table, * notebook,
+    * ip_table, * font_table, * goal_kc_table;
+
+  dialog = gtk_dialog_new_with_buttons (_("Customize"),
+					GTK_WINDOW (window),
+					GTK_DIALOG_MODAL,
+					GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
+					GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+					NULL);
+
+  content = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+
+  notebook = gtk_notebook_new ();
+
+  /* Set up the customization run through. */
+
+  int i, j;
+
+  GtkWidget * tables[] = {main_kc_table, goal_kc_table,
+			  font_table, ip_table};
+  conf_obj * confs[] = {main_menu_conf, goal_menu_conf,
+			 display_conf, grade_conf};
+
+  int sizes[] = {25, 5, 10, 2};
+  char * labels[] = {_("Main Keys"), _("Goal Keys"), _("Display"), _("Grade Server")};
+
+  // Run it for all of the configuration tables.
+  for (j = 0; j < 4; j++)
+    {
+      tables[j] = gtk_table_new (13, 4, FALSE);
+      for (i = 0; i < sizes[j]; i++)
+	{
+	  GtkWidget * label;
+	  conf_obj cur_obj;
+
+	  cur_obj = confs[j][i];
+
+	  confs[j][i].widget = confs[j][i].value_func (&confs[j][i], 1);
+	  label = gtk_label_new (confs[j][i].label);
+	  gtk_widget_set_tooltip_text (label, confs[j][i].tooltip);
+
+	  gtk_widget_set_tooltip_text (confs[j][i].widget,
+				       confs[j][i].tooltip);
+
+	  int col;
+	  col = i / 13;
+	  col *= 2;
+
+	  gtk_table_attach_defaults (GTK_TABLE (tables[j]), label,
+				     col, col + 1,
+				     i % 13, i % 13 + 1);
+
+	  gtk_table_attach_defaults (GTK_TABLE (tables[j]), confs[j][i].widget,
+				     col + 1, col + 2,
+				     i % 13, i % 13 + 1);
+	}
+
+      GtkWidget * tbl_label;
+
+      tbl_label = gtk_label_new (labels[j]);
+      gtk_notebook_append_page (GTK_NOTEBOOK (notebook), tables[j],
+				tbl_label);
+    }
+
+  gtk_container_add (GTK_CONTAINER (content), notebook);
+  gtk_widget_show_all (dialog);
+
+  int problem = 1;
+
+  while (problem)
+    {
+      if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
+	{
+	  problem = 0;
+	  /* First, confirm that each entry is unique. */
+	  for (j = 0; j < 2; j++)
+	    {
+	      int k;
+	      conf_obj obj_i, obj_k;
+
+	      for (i = 0; i < sizes[j]; i++)
+		{
+		  obj_i = confs[j][i];
+		  const char * str_i;
+		  str_i = gtk_entry_get_text (GTK_ENTRY (obj_i.widget));
+
+		  if (str_i[0] == '\0')
+		    continue;
+
+		  for (k = 0; k < sizes[j]; k++)
+		    {
+		      if (i == k)
+			continue;
+
+		      obj_k = confs[j][k];
+
+		      const char * str_k;
+		      str_k = gtk_entry_get_text (GTK_ENTRY (obj_k.widget));
+
+		      if (str_k[0] == '\0')
+			continue;
+
+		      if (!strcmp (str_i, str_k))
+			{
+			  // The same key has been assigned to
+			  // two different commands.
+
+			  GtkWidget * err_dialog;
+
+			  err_dialog
+			    = gtk_message_dialog_new (GTK_WINDOW (dialog),
+						      GTK_DIALOG_MODAL,
+						      GTK_MESSAGE_ERROR,
+						      GTK_BUTTONS_CLOSE,
+						      _("There are two commands with the same key\nPlease change this."));
+			  gtk_dialog_run (GTK_DIALOG (err_dialog));
+			  problem = 1;
+			  gtk_widget_destroy (err_dialog);
+			  break;
+			}
+		    }
+
+		  if (problem == 1)
+		    break;
+		}
+
+	      if (problem == 1)
+		break;
+	    }
+
+	  if (problem == 1)
+	    continue;
+
+	  problem = 0;
+
+	  FILE * conf_file;
+	  char * path, * home_dir;
+	  int alloc_size, path_pos = 0;
+
+	  home_dir = getenv ("HOME");
+	  if (!home_dir)
+	    home_dir = getenv ("HOMEPATH");
+
+#ifdef WIN32
+	  alloc_size += strlen (getenv ("HOMEDRIVE")) + 1;
+#endif
+	  path = (char *) calloc (alloc_size + 1, sizeof (char));
+	  CHECK_ALLOC (path, -1);
+
+#ifdef WIN32
+	  path_pos += sprintf (path, "%s\\", getenv ("HOMEDRIVE"));
+#endif
+
+	  sprintf (path + path_pos, "%s/%s", home_dir, CONF_FILE);
+
+	  conf_file = fopen (path, "w");
+	  if (!conf_file)
+	    {
+	      perror (NULL);
+	      gtk_widget_destroy (dialog);
+	      return -2;
+	    }
+	  free (path);
+
+	  for (j = 0; j < 4; j++)
+	    {
+	      tables[j] = gtk_table_new (13, 4, FALSE);
+
+	      for (i = 0; i < sizes[j]; i++)
+		{
+		  GtkWidget * label;
+		  conf_obj cur_obj;
+		  char * print_str;
+
+		  cur_obj = confs[j][i];
+		  print_str = cur_obj.value_func (&cur_obj, 0);
+
+		  if (print_str)
+		    {
+		      fprintf (conf_file, "%s", print_str);
+		      free (print_str);
+		    }
+		}
+	    }
+
+	  fclose (conf_file);
+
+	  the_app_read_config_file (the_app);
+	}
+      else
+	{
+	  problem = 0;
+	}
+    }
+
+  gtk_widget_destroy (dialog);
+
+  return 0;
+}
+
+/* Runs the submission dialog.
+ *  input:
+ *   ap - the proof being submitted.
+ *  output:
+ *   0 on success, -1 on memory error.
+ */
+int
+gui_submit_show (GtkWidget * window)
+{
+  // Dialog [Submit / Cancel]
+  //  - VBox
+  //    - HBox
+  //      - GtkLabel "Homework: "
+  //      - GtkEdit [      ]
+  //    - HBox
+  //      - GtkLabel "Email: "
+  //      - GtkEdit [      ]
+  //    - HBox
+  //      - GtkLabel "Instructor's Email (optional): "
+  //      - GtkEdit [      ]
+
+  GtkWidget * dialog, * content, * table;
+  GtkWidget * user_label, * user_entry, * instr_label, * instr_entry;
+
+  dialog = gtk_dialog_new_with_buttons (_("Submit Proofs"),
+					GTK_WINDOW (window),
+					GTK_DIALOG_MODAL,
+					GTK_STOCK_OK, GTK_RESPONSE_OK,
+					GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+					NULL);
+
+  content = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+
+  table = gtk_table_new (4 + the_app->guis->num_stuff, 2, FALSE);
+
+  user_label = gtk_label_new (_("Your Email: "));
+  user_entry = gtk_entry_new ();
+  gtk_table_attach_defaults (GTK_TABLE (table), user_label, 0, 1, 0, 1);
+  gtk_table_attach_defaults (GTK_TABLE (table), user_entry, 1, 2, 0, 1);
+
+  instr_label = gtk_label_new (_("(Optional) Instructor's Email: "));
+  instr_entry = gtk_entry_new ();
+  gtk_table_attach_defaults (GTK_TABLE (table), instr_label, 0, 1, 1, 2);
+  gtk_table_attach_defaults (GTK_TABLE (table), instr_entry, 1, 2, 1, 2);
+
+  GtkWidget * sep_label;
+
+  sep_label = gtk_label_new (_("    "));
+  gtk_table_attach_defaults (GTK_TABLE (table), sep_label, 0, 2, 2, 3);
+
+  GtkWidget * proof_label, * hw_label;
+
+  hw_label = gtk_label_new (_("Problem"));
+  proof_label = gtk_label_new (_("File Name"));
+
+  gtk_table_attach_defaults (GTK_TABLE (table), hw_label, 0, 1, 3, 4);
+  gtk_table_attach_defaults (GTK_TABLE (table), proof_label, 1, 2, 3, 4);
+
+  item_t * g_itr;
+  int i = 4;
+
+  for (g_itr = the_app->guis->head; g_itr; g_itr = g_itr->next)
+    {
+      GtkWidget * label, * entry;
+      aris_proof * ap;
+
+      ap = g_itr->value;
+
+      if (ap->cur_file)
+	{
+
+	  label = gtk_label_new (ap->cur_file);
+	  entry = gtk_entry_new ();
+
+	  gtk_table_attach_defaults (GTK_TABLE (table), entry, 0, 1, i, i + 1);
+	  gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, i, i + 1);
+	  
+	  i++;
+	}
+    }
+
+  if (i == 4)
+    {
+      GtkWidget * label;
+      label = gtk_label_new (_("Please save your work first."));
+      gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 2, i, i + 1);
+      gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog), GTK_RESPONSE_OK, FALSE);
+    }
+
+  gtk_container_add (GTK_CONTAINER (content), table);
+  gtk_widget_show_all (table);
+
+  int response;
+
+  if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK)
+    {
+      const char * user_email, * instr_email;
+      struct submit_ent * entries;
+
+      user_email = gtk_entry_get_text (GTK_ENTRY (user_entry));
+      instr_email = gtk_entry_get_text (GTK_ENTRY (instr_entry));
+
+      entries = (struct submit_ent *) calloc (the_app->guis->num_stuff + 1,
+					       sizeof (struct submit_ent));
+      CHECK_ALLOC (entries, -1);
+
+      GList * gl;
+      i = 0;
+
+      gl = gtk_container_get_children (GTK_CONTAINER (table));
+
+      while (gl)
+	{
+	  GtkWidget * wid;
+
+	  wid = gl->data;
+
+	  if (GTK_IS_LABEL (wid)
+	      && !strcmp (gtk_label_get_label (GTK_LABEL (wid)),
+			  _("File Name")))
+	    {
+	      break;
+	    }
+
+	  GtkWidget * ent;
+
+	  ent = gl->next->data;
+	  const char * entry_text = gtk_entry_get_text (GTK_ENTRY (ent));
+
+
+	  entries[i].hw = strdup (entry_text);
+	  entries[i].file_name = strdup (gtk_label_get_label (GTK_LABEL (wid)));
+
+	  i++;
+	  gl = gl->next->next;
+	}
+
+      entries[i].hw = entries[i].file_name = NULL;
+
+      int num_ents = i;
+
+      int rc;
+      rc = the_app_submit (user_email, instr_email, entries);
+      if (rc == -3)
+	{
+	  GtkWidget * error_dialog;
+	  error_dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+						 GTK_DIALOG_DESTROY_WITH_PARENT,
+						 GTK_MESSAGE_ERROR,
+						 GTK_BUTTONS_CLOSE,
+						 "Unable to submit files to server: %s",
+						 the_app->ip_addr);
+	  gtk_dialog_run (GTK_DIALOG (error_dialog));
+	  gtk_widget_destroy (error_dialog);
+	}
+
+      for (i = 0; i < num_ents; i++)
+	{
+	  free (entries[i].hw);
+	  free (entries[i].file_name);
+	}
+
+      free (entries);
+    }
+
+  gtk_widget_destroy (dialog);
+
+  return 0;
+}
+
 /* Handles the menu activation for an aris proof.
  *  input:
  *    ap - the aris proof for which the menu activation is being handled.
@@ -1025,8 +1379,8 @@ menu_activated (aris_proof * ap, int menu_id)
       font_sel = (GtkWidget *) g_list_nth_data (gl, SEN_PARENT (ap)->font);
 
       font_small = (GtkWidget *) g_list_first (gl)->data;
-      font_medium = (GtkWidget *) g_list_first(gl)->next->data;
-      font_large = (GtkWidget *) g_list_first(gl)->next->next->data;
+      font_medium = (GtkWidget *) g_list_first (gl)->next->data;
+      font_large = (GtkWidget *) g_list_first (gl)->next->next->data;
     }
 
   switch (menu_id)
@@ -1034,9 +1388,11 @@ menu_activated (aris_proof * ap, int menu_id)
     case MENU_NEW:
       ret = gui_new (ap);
       break;
+
     case MENU_OPEN:
       ret = gui_open (SEN_PARENT (ap)->window);
       break;
+
     case MENU_SAVE:
       ret = gui_save (ap, 0);
       if (ret < 0)
@@ -1044,6 +1400,7 @@ menu_activated (aris_proof * ap, int menu_id)
 
       aris_proof_set_sb (ap, _("Proof Saved."));
       break;
+
     case MENU_SAVE_AS:
       ret = gui_save (ap, 1);
       if (ret < 0)
@@ -1051,19 +1408,30 @@ menu_activated (aris_proof * ap, int menu_id)
 
       aris_proof_set_sb (ap, _("Proof Saved."));
       break;
+
     case MENU_CLOSE:
       gui_destroy (ap);
       break;
+
     case MENU_QUIT:
       app_quit ();
       break;
+
     case MENU_ADD_PREM:
+      if (the_app->verbose)
+	printf ("Inserting premise\n");
+
+      // The second time, it happened in here.
+      // double free or corruption
+      // pango_glyph_string_free
+      // gtk_text_layout_free_line_display
       sen = aris_proof_create_new_prem (ap);
       if (!sen)
 	return -1;
 
       aris_proof_set_sb (ap, _("Premise Created."));
       break;
+
     case MENU_ADD_CONC:
       sen = aris_proof_create_new_conc (ap);
       if (!sen)
@@ -1071,6 +1439,7 @@ menu_activated (aris_proof * ap, int menu_id)
 
       aris_proof_set_sb (ap, _("Conclusion Created."));
       break;
+
     case MENU_ADD_SUB:
       sen = aris_proof_create_new_sub (ap);
       if (!sen)
@@ -1078,6 +1447,7 @@ menu_activated (aris_proof * ap, int menu_id)
 
       aris_proof_set_sb (ap, _("Subproof Created."));
       break;
+
     case MENU_END_SUB:
       sen = aris_proof_end_sub (ap);
       if (!sen)
@@ -1085,6 +1455,7 @@ menu_activated (aris_proof * ap, int menu_id)
 
       aris_proof_set_sb (ap, _("Subproof Ended."));
       break;
+
     case MENU_COPY:
       ret = aris_proof_copy (ap);
       if (ret < 0)
@@ -1092,6 +1463,7 @@ menu_activated (aris_proof * ap, int menu_id)
 
       aris_proof_set_sb (ap, _("Sentence Copied."));
       break;
+
     case MENU_KILL:
       ret = aris_proof_kill (ap);
       if (ret < 0)
@@ -1102,26 +1474,43 @@ menu_activated (aris_proof * ap, int menu_id)
       else
 	aris_proof_set_sb (ap, _("Sentence Killed."));
       break;
+
     case MENU_INSERT:
       ret = aris_proof_yank (ap);
       aris_proof_set_sb (ap, _("Sentence Inserted."));
       break;
+
     case MENU_EVAL_LINE:
       ls_clear (ap->vars);
       evaluate_line (ap, SENTENCE (SEN_PARENT (ap)->focused->value));
       break;
+
     case MENU_EVAL_PROOF:
       ret = evaluate_proof (ap);
       break;
+
     case MENU_GOAL:
       gui_goal_check (ap);
       break;
+
+      /*
+    case MENU_SUBMIT:
+      gui_submit_show (ap);
+      break;
+      */
+
     case MENU_BOOLEAN:
       aris_proof_toggle_boolean_mode (ap);
       break;
+
+    case MENU_IMPORT:
+      aris_proof_import_proof (ap);
+      break;
+
     case MENU_TOGGLE_RULES:
       gui_toggle_rules (ap);
       break;
+
     case MENU_SMALL:
       if (SEN_PARENT (ap)->font != FONT_TYPE_SMALL)
 	{
@@ -1132,6 +1521,7 @@ menu_activated (aris_proof * ap, int menu_id)
 	}
 
       break;
+
     case MENU_MEDIUM:
       if (SEN_PARENT (ap)->font != FONT_TYPE_MEDIUM)
 	{
@@ -1141,6 +1531,7 @@ menu_activated (aris_proof * ap, int menu_id)
 	  gtk_widget_set_sensitive (font_medium, FALSE);
 	}
       break;
+
     case MENU_LARGE:
       if (SEN_PARENT (ap)->font != FONT_TYPE_LARGE)
 	{
@@ -1150,6 +1541,7 @@ menu_activated (aris_proof * ap, int menu_id)
 	  gtk_widget_set_sensitive (font_large, FALSE);
 	}
       break;
+
     case MENU_CUSTOM:
       if (gtk_widget_get_sensitive (font_sel))
 	{
@@ -1170,6 +1562,7 @@ menu_activated (aris_proof * ap, int menu_id)
 	  aris_proof_set_font (ap, FONT_TYPE_CUSTOM);
 	}
       break;
+
     case MENU_CONTENTS:
       ret = gui_help ();
       if (ret < 0)
@@ -1177,6 +1570,8 @@ menu_activated (aris_proof * ap, int menu_id)
 
       aris_proof_set_sb (ap, _("Displaying Help."));
       break;
+
+
     case MENU_ABOUT:
       gui_about (SEN_PARENT (ap)->window);
       break;
