@@ -1,6 +1,6 @@
 /*  The doubly-linked list structure.
 
-   Copyright (C) 2012 Ian Dunn.
+   Copyright (C) 2012, 2013 Ian Dunn.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -19,8 +19,7 @@
 #ifndef ARIS_LIST_H
 #define ARIS_LIST_H
 
-typedef struct item item_t;
-typedef struct list list_t;
+#include "typedef.h"
 
 // The item structure of the doubly-linked list.
 
